@@ -17,10 +17,10 @@
 package org.apache.kyuubi.sql
 
 import org.apache.spark.sql.SparkSession
-import org.apache.spark.sql.catalyst.analysis.{UnresolvedFunctionName, UnresolvedRelation}
-import org.apache.spark.sql.catalyst.plans.logical._
+import org.apache.spark.sql.catalyst.analysis.{UnresolvedFunc, UnresolvedRelation, UnresolvedTableOrView, UnresolvedView}
+import org.apache.spark.sql.catalyst.plans.logical.{DropFunction, DropNamespace, DropTable, DropView, LogicalPlan, NoopCommand, UncacheTable}
 import org.apache.spark.sql.catalyst.rules.Rule
-import org.apache.spark.sql.execution.command.{AlterTableDropPartitionCommand, DropFunctionCommand, DropTableCommand}
+import org.apache.spark.sql.execution.command.{AlterTableDropPartitionCommand, DropTableCommand}
 
 import org.apache.kyuubi.sql.KyuubiSQLConf._
 
@@ -33,18 +33,16 @@ case class DropIgnoreNonexistent(session: SparkSession) extends Rule[LogicalPlan
           i.copy(ifExists = true)
         case i @ DropTableCommand(_, false, _, _) =>
           i.copy(ifExists = true)
-        case i @ DropTable(_, false, _) =>
-          i.copy(ifExists = true)
         case i @ DropNamespace(_, false, _) =>
           i.copy(ifExists = true)
-        case i @ DropFunctionCommand(_, false, _) =>
-          i.copy(ifExists = true)
-        case i @ DropView(_, false) =>
-          i.copy(ifExists = true)
-        // refer: org.apache.spark.sql.catalyst.analysis.ResolveCommandsWithIfExists
+        // like: org.apache.spark.sql.catalyst.analysis.ResolveCommandsWithIfExists
+        case DropTable(u: UnresolvedTableOrView, false, _) =>
+          NoopCommand("DROP TABLE", u.multipartIdentifier)
+        case DropView(u: UnresolvedView, false) =>
+          NoopCommand("DROP VIEW", u.multipartIdentifier)
         case UncacheTable(u: UnresolvedRelation, false, _) =>
           NoopCommand("UNCACHE TABLE", u.multipartIdentifier)
-        case DropFunction(u: UnresolvedFunctionName, false) =>
+        case DropFunction(u: UnresolvedFunc, false) =>
           NoopCommand("DROP FUNCTION", u.multipartIdentifier)
         case _ => plan
       }
