@@ -20,29 +20,29 @@ package org.apache.spark.sql
 import org.apache.spark.sql.catalyst.expressions.Attribute
 import org.apache.spark.sql.catalyst.plans.logical.{LogicalPlan, RebalancePartitions, Sort}
 import org.apache.spark.sql.execution.command.DataWritingCommand
-import org.apache.spark.sql.execution.datasources.InsertIntoHadoopFsRelationCommand
 import org.apache.spark.sql.hive.HiveUtils
-import org.apache.spark.sql.hive.execution.InsertIntoHiveTable
+import org.apache.spark.sql.hive.execution.OptimizedCreateHiveTableAsSelectCommand
 
 import org.apache.kyuubi.sql.KyuubiSQLConf
 
 class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
 
   test("check rebalance exists") {
-    def check(df: => DataFrame, expectedRebalanceNum: Int = 1): Unit = {
+    def check(
+        df: => DataFrame,
+        expectedRebalanceNumEnabled: Int = 1,
+        expectedRebalanceNumDisabled: Int = 0): Unit = {
       withSQLConf(KyuubiSQLConf.INSERT_REPARTITION_BEFORE_WRITE_IF_NO_SHUFFLE.key -> "true") {
-        withListener(df) { write =>
-          assert(write.collect {
+        assert(
+          df.queryExecution.analyzed.collect {
             case r: RebalancePartitions => r
-          }.size == expectedRebalanceNum)
-        }
+          }.size == expectedRebalanceNumEnabled)
       }
       withSQLConf(KyuubiSQLConf.INSERT_REPARTITION_BEFORE_WRITE_IF_NO_SHUFFLE.key -> "false") {
-        withListener(df) { write =>
-          assert(write.collect {
+        assert(
+          df.queryExecution.analyzed.collect {
             case r: RebalancePartitions => r
-          }.isEmpty)
-        }
+          }.size == expectedRebalanceNumDisabled)
       }
     }
 
@@ -72,6 +72,14 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
           check(sql("INSERT INTO TABLE tmp1 SELECT * FROM VALUES(1),(2),(3) AS t(c1)"))
         }
 
+        withTable("tmp1") {
+          sql(s"CREATE TABLE tmp1 (c1 int) $storage")
+          check(
+            sql("INSERT INTO TABLE tmp1 SELECT /*+ REBALANCE */ * FROM VALUES(1),(2),(3) AS t(c1)"),
+            1,
+            1)
+        }
+
         withTable("tmp1", "tmp2") {
           sql(s"CREATE TABLE tmp1 (c1 int) $storage")
           sql(s"CREATE TABLE tmp2 (c1 int) $storage")
@@ -98,11 +106,10 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
 
   test("check rebalance does not exists") {
     def check(df: DataFrame): Unit = {
-      withListener(df) { write =>
-        assert(write.collect {
+      assert(
+        df.queryExecution.analyzed.collect {
           case r: RebalancePartitions => r
         }.isEmpty)
-      }
     }
 
     withSQLConf(
@@ -136,20 +143,26 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
           sql(s"CREATE TABLE tmp1 (c1 int) $storage")
           check(sql("INSERT INTO TABLE tmp1 SELECT * FROM VALUES(1),(2),(3) AS t(c1)"))
         }
+
+        withTable("tmp1") {
+          sql(s"CREATE TABLE tmp1 $storage AS SELECT * FROM VALUES(1),(2),(3) AS t(c1)")
+        }
+
+        withTable("tmp1") {
+          sql(s"CREATE TABLE tmp1 $storage PARTITIONED BY(c2) AS " +
+            s"SELECT * FROM VALUES(1, 'a'),(2, 'b') AS t(c1, c2)")
+        }
       }
     }
   }
 
   test("test dynamic partition write") {
-    def checkRepartitionExpression(sqlString: String): Unit = {
-      withListener(sqlString) { write =>
-        assert(write.isInstanceOf[InsertIntoHiveTable])
-        assert(write.collect {
-          case r: RebalancePartitions if r.partitionExpressions.size == 1 =>
-            assert(r.partitionExpressions.head.asInstanceOf[Attribute].name === "c2")
-            r
-        }.size == 1)
-      }
+    def checkRepartitionExpression(df: DataFrame): Unit = {
+      assert(df.queryExecution.analyzed.collect {
+        case r: RebalancePartitions if r.partitionExpressions.size == 1 =>
+          assert(r.partitionExpressions.head.asInstanceOf[Attribute].name === "c2")
+          r
+      }.size == 1)
     }
 
     withSQLConf(
@@ -158,12 +171,12 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
       Seq("USING PARQUET", "").foreach { storage =>
         withTable("tmp1") {
           sql(s"CREATE TABLE tmp1 (c1 int) $storage PARTITIONED BY (c2 string)")
-          checkRepartitionExpression("INSERT INTO TABLE tmp1 SELECT 1 as c1, 'a' as c2 ")
+          checkRepartitionExpression(sql("INSERT INTO TABLE tmp1 SELECT 1 as c1, 'a' as c2 "))
         }
 
         withTable("tmp1") {
           checkRepartitionExpression(
-            "CREATE TABLE tmp1 PARTITIONED BY(C2) SELECT 1 as c1, 'a' as c2")
+            sql("CREATE TABLE tmp1 PARTITIONED BY(C2) SELECT 1 as c1, 'a' as c2 "))
         }
       }
     }
@@ -175,12 +188,15 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
       HiveUtils.CONVERT_METASTORE_CTAS.key -> "true",
       KyuubiSQLConf.INSERT_REPARTITION_BEFORE_WRITE_IF_NO_SHUFFLE.key -> "true") {
       withTable("t") {
-        withListener("CREATE TABLE t STORED AS parquet AS SELECT 1 as a") { write =>
-          assert(write.isInstanceOf[InsertIntoHadoopFsRelationCommand])
-          assert(write.collect {
-            case _: RebalancePartitions => true
-          }.size == 1)
+        val df = sql(s"CREATE TABLE t STORED AS parquet AS SELECT 1 as a")
+        val ctas = df.queryExecution.analyzed.collect {
+          case _: OptimizedCreateHiveTableAsSelectCommand => true
         }
+        assert(ctas.size == 1)
+        val repartition = df.queryExecution.analyzed.collect {
+          case _: RebalancePartitions => true
+        }
+        assert(repartition.size == 1)
       }
     }
   }
@@ -198,10 +214,9 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
     }
 
     withView("v") {
-      withTable("t", "t2", "input1", "input2") {
+      withTable("t", "input1", "input2") {
         withSQLConf(KyuubiSQLConf.INFER_REBALANCE_AND_SORT_ORDERS.key -> "true") {
           sql(s"CREATE TABLE t (c1 int, c2 long) USING PARQUET PARTITIONED BY (p string)")
-          sql(s"CREATE TABLE t2 (c1 int, c2 long, c3 long) USING PARQUET PARTITIONED BY (p string)")
           sql(s"CREATE TABLE input1 USING PARQUET AS SELECT * FROM VALUES(1,2),(1,3)")
           sql(s"CREATE TABLE input2 USING PARQUET AS SELECT * FROM VALUES(1,3),(1,3)")
           sql(s"CREATE VIEW v as SELECT col1, count(*) as col2 FROM input1 GROUP BY col1")
@@ -264,30 +279,6 @@ class RebalanceBeforeWritingSuite extends KyuubiSparkSQLExtensionTest {
                |SELECT * FROM v
                |""".stripMargin)
           checkShuffleAndSort(df5.queryExecution.analyzed, 1, 1)
-
-          // generate
-          val df6 = sql(
-            s"""
-               |INSERT INTO TABLE t2 PARTITION(p='a')
-               |SELECT /*+ broadcast(input2) */ input1.col1, input2.col1, cast(cc.action1 as bigint)
-               |FROM input1
-               |JOIN input2
-               |ON input1.col1 = input2.col1
-               |  lateral view explode(ARRAY(input1.col1, input1.col2)) cc as action1
-               |""".stripMargin)
-          checkShuffleAndSort(df6.queryExecution.analyzed, 1, 1)
-
-          // window
-          val df7 = sql(
-            s"""
-               |INSERT INTO TABLE t2 PARTITION(p='a')
-               |SELECT /*+ broadcast(input2) */ input1.col1, input2.col2,
-               | RANK() OVER (PARTITION BY input2.col2 ORDER BY input1.col1) AS rank
-               |FROM input1
-               |JOIN input2
-               |ON input1.col1 = input2.col1
-               |""".stripMargin)
-          checkShuffleAndSort(df7.queryExecution.analyzed, 1, 1)
         }
       }
     }
