@@ -54,11 +54,15 @@ sealed trait Descriptor {
    */
   def extract(v: AnyRef): AnyRef
 
+  def comment: String
+
   final def error(v: AnyRef, e: Throwable): String = {
     val resourceName = getClass.getSimpleName.stripSuffix("Desc")
     val objectClass = v.getClass.getName
     s"[Spark$SPARK_VERSION] failed to get $resourceName from $objectClass by" +
-      s" $fieldExtractor/$fieldName, due to ${e.getMessage}"
+      s" $fieldExtractor/$fieldName, " +
+      (if (comment.nonEmpty) s"desc comment: ${comment}") +
+      s"due to ${e.getMessage}"
   }
 }
 
@@ -70,7 +74,8 @@ sealed trait Descriptor {
  */
 case class ColumnDesc(
     fieldName: String,
-    fieldExtractor: String) extends Descriptor {
+    fieldExtractor: String,
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Seq[String] = {
     val columnsVal = invokeAs[AnyRef](v, fieldName)
     val columnExtractor = lookupExtractor[ColumnExtractor](fieldExtractor)
@@ -89,7 +94,8 @@ case class DatabaseDesc(
     fieldName: String,
     fieldExtractor: String,
     catalogDesc: Option[CatalogDesc] = None,
-    isInput: Boolean = false) extends Descriptor {
+    isInput: Boolean = false,
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Database = {
     val databaseVal = invokeAs[AnyRef](v, fieldName)
     val databaseExtractor = lookupExtractor[DatabaseExtractor](fieldExtractor)
@@ -113,7 +119,8 @@ case class DatabaseDesc(
 case class FunctionTypeDesc(
     fieldName: String,
     fieldExtractor: String,
-    skipTypes: Seq[String]) extends Descriptor {
+    skipTypes: Seq[String],
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): FunctionType = {
     extract(v, SparkSession.active)
   }
@@ -143,7 +150,8 @@ case class FunctionDesc(
     fieldExtractor: String,
     databaseDesc: Option[DatabaseDesc] = None,
     functionTypeDesc: Option[FunctionTypeDesc] = None,
-    isInput: Boolean = false) extends Descriptor {
+    isInput: Boolean = false,
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Function = {
     val functionVal = invokeAs[AnyRef](v, fieldName)
     val functionExtractor = lookupExtractor[FunctionExtractor](fieldExtractor)
@@ -168,7 +176,8 @@ case class FunctionDesc(
  */
 case class QueryDesc(
     fieldName: String,
-    fieldExtractor: String = "LogicalPlanQueryExtractor") extends Descriptor {
+    fieldExtractor: String = "LogicalPlanQueryExtractor",
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Option[LogicalPlan] = {
     val queryVal = invokeAs[AnyRef](v, fieldName)
     val queryExtractor = lookupExtractor[QueryExtractor](fieldExtractor)
@@ -186,7 +195,8 @@ case class QueryDesc(
 case class TableTypeDesc(
     fieldName: String,
     fieldExtractor: String,
-    skipTypes: Seq[String]) extends Descriptor {
+    skipTypes: Seq[String],
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): TableType = {
     extract(v, SparkSession.active)
   }
@@ -224,7 +234,8 @@ case class TableDesc(
     tableTypeDesc: Option[TableTypeDesc] = None,
     catalogDesc: Option[CatalogDesc] = None,
     isInput: Boolean = false,
-    setCurrentDatabaseIfMissing: Boolean = false) extends Descriptor {
+    setCurrentDatabaseIfMissing: Boolean = false,
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Option[Table] = {
     extract(v, SparkSession.active)
   }
@@ -254,7 +265,8 @@ case class TableDesc(
 case class ActionTypeDesc(
     fieldName: String = null,
     fieldExtractor: String = null,
-    actionType: Option[String] = None) extends Descriptor {
+    actionType: Option[String] = None,
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): PrivilegeObjectActionType = {
     actionType.map(PrivilegeObjectActionType.withName).getOrElse {
       val actionTypeVal = invokeAs[AnyRef](v, fieldName)
@@ -272,7 +284,8 @@ case class ActionTypeDesc(
  */
 case class CatalogDesc(
     fieldName: String = "catalog",
-    fieldExtractor: String = "CatalogPluginCatalogExtractor") extends Descriptor {
+    fieldExtractor: String = "CatalogPluginCatalogExtractor",
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Option[String] = {
     val catalogVal = invokeAs[AnyRef](v, fieldName)
     val catalogExtractor = lookupExtractor[CatalogExtractor](fieldExtractor)
@@ -283,7 +296,8 @@ case class CatalogDesc(
 case class ScanDesc(
     fieldName: String,
     fieldExtractor: String,
-    catalogDesc: Option[CatalogDesc] = None) extends Descriptor {
+    catalogDesc: Option[CatalogDesc] = None,
+    comment: String = "") extends Descriptor {
   override def extract(v: AnyRef): Option[Table] = {
     extract(v, SparkSession.active)
   }
@@ -306,3 +320,26 @@ case class ScanDesc(
     }
   }
 }
+
+/**
+ * URI Descriptor
+ *
+ * @param fieldName the field name or method name of this uri field
+ * @param fieldExtractor the key of a [[URIExtractor]] instance
+ * @param isInput read or write
+ */
+case class UriDesc(
+    fieldName: String,
+    fieldExtractor: String,
+    isInput: Boolean = false,
+    comment: String = "") extends Descriptor {
+  override def extract(v: AnyRef): Seq[Uri] = {
+    extract(v, SparkSession.active)
+  }
+
+  def extract(v: AnyRef, spark: SparkSession): Seq[Uri] = {
+    val uriVal = invokeAs[AnyRef](v, fieldName)
+    val uriExtractor = lookupExtractor[URIExtractor](fieldExtractor)
+    uriExtractor(spark, uriVal)
+  }
+}
