@@ -20,7 +20,23 @@ package org.apache.kyuubi.plugin.spark.authz.gen
 import org.apache.kyuubi.plugin.spark.authz.OperationType._
 import org.apache.kyuubi.plugin.spark.authz.serde._
 
-object DatabaseCommands {
+object DatabaseCommands extends CommandSpecs[DatabaseCommandSpec] {
+
+  val CreateDatabaseCommand = {
+    DatabaseCommandSpec(
+      "org.apache.spark.sql.execution.command.CreateDatabaseCommand",
+      Seq(DatabaseDesc("databaseName", classOf[StringDatabaseExtractor])),
+      CREATEDATABASE,
+      Seq(UriDesc("path", classOf[StringURIExtractor])))
+  }
+
+  val AlterDatabaseSetLocationCommand = {
+    DatabaseCommandSpec(
+      "org.apache.spark.sql.execution.command.AlterDatabaseSetLocationCommand",
+      Seq(DatabaseDesc("databaseName", classOf[StringDatabaseExtractor])),
+      ALTERDATABASE_LOCATION,
+      Seq(UriDesc("location", classOf[StringURIExtractor])))
+  }
 
   val AlterDatabaseProperties = {
     DatabaseCommandSpec(
@@ -47,7 +63,8 @@ object DatabaseCommands {
     DatabaseCommandSpec(
       "org.apache.spark.sql.catalyst.plans.logical.SetNamespaceLocation",
       Seq(DatabaseDesc("namespace", classOf[ResolvedNamespaceDatabaseExtractor])),
-      ALTERDATABASE_LOCATION)
+      ALTERDATABASE_LOCATION,
+      Seq(UriDesc("location", classOf[StringURIExtractor])))
   }
 
   val CreateNamespace = {
@@ -62,7 +79,8 @@ object DatabaseCommands {
     DatabaseCommandSpec(
       "org.apache.spark.sql.catalyst.plans.logical.CreateNamespace",
       Seq(databaseDesc1, databaseDesc2, databaseDesc3),
-      CREATEDATABASE)
+      CREATEDATABASE,
+      Seq(UriDesc("properties", classOf[PropertiesLocationUriExtractor])))
   }
 
   val DropNamespace = {
@@ -141,18 +159,14 @@ object DatabaseCommands {
     DatabaseCommandSpec(cmd, Seq(databaseDesc), DESCDATABASE)
   }
 
-  val data: Array[DatabaseCommandSpec] = Array(
+  override def specs: Seq[DatabaseCommandSpec] = Seq(
     AlterDatabaseProperties,
-    AlterDatabaseProperties.copy(
-      classname = "org.apache.spark.sql.execution.command.AlterDatabaseSetLocationCommand",
-      opType = ALTERDATABASE_LOCATION),
-    AlterDatabaseProperties.copy(
-      classname = "org.apache.spark.sql.execution.command.CreateDatabaseCommand",
-      opType = CREATEDATABASE),
+    AlterDatabaseSetLocationCommand,
     AlterDatabaseProperties.copy(
       classname = "org.apache.spark.sql.execution.command.DropDatabaseCommand",
       opType = DROPDATABASE),
     AnalyzeTables,
+    CreateDatabaseCommand,
     CreateNamespace,
     CommentOnNamespace,
     DescribeDatabase,
