@@ -19,13 +19,13 @@
 select
     l_returnflag,
     l_linestatus,
-    sum(l_quantity) as sum_qty,
-    sum(l_extendedprice) as sum_base_price,
-    sum(l_extendedprice * (1 - l_discount)) as sum_disc_price,
-    sum(l_extendedprice * (1 - l_discount) * (1 + l_tax)) as sum_charge,
-    avg(l_quantity) as avg_qty,
-    avg(l_extendedprice) as avg_price,
-    avg(l_discount) as avg_disc,
+    round(sum(l_quantity), 2) as sum_qty,
+    round(sum(l_extendedprice), 2) as sum_base_price,
+    round(sum(l_extendedprice * (1 - l_discount)), 2) as sum_disc_price,
+    round(sum(l_extendedprice * (1 - l_discount) * (1 + l_tax)), 2) as sum_charge,
+    round(avg(l_quantity), 2) as avg_qty,
+    round(avg(l_extendedprice), 2) as avg_price,
+    round(avg(l_discount), 2) as avg_disc,
     count(*) as count_order
 from
     lineitem
