@@ -45,7 +45,7 @@ class JdbcSessionImpl(
 
   private var databaseMetaData: DatabaseMetaData = _
 
-  private val kyuubiConf: KyuubiConf = normalizeConf
+  val sessionConf: KyuubiConf = normalizeConf
 
   private def normalizeConf: KyuubiConf = {
     val kyuubiConf = sessionManager.getConf.clone
@@ -60,13 +60,13 @@ class JdbcSessionImpl(
   override def open(): Unit = {
     info(s"Starting to open jdbc session.")
     if (sessionConnection == null) {
-      sessionConnection = ConnectionProvider.create(kyuubiConf)
+      sessionConnection = ConnectionProvider.create(sessionConf)
       databaseMetaData = sessionConnection.getMetaData
     }
     KyuubiJdbcUtils.initializeJdbcSession(
-      kyuubiConf,
+      sessionConf,
       sessionConnection,
-      kyuubiConf.get(ENGINE_JDBC_SESSION_INITIALIZE_SQL))
+      sessionConf.get(ENGINE_JDBC_SESSION_INITIALIZE_SQL))
     super.open()
     info(s"The jdbc session is started.")
   }
