@@ -21,7 +21,7 @@ import org.apache.kyuubi.ctl.util.CtlUtils
 import org.apache.kyuubi.ha.client.ServiceNodeInfo
 
 class ListServerCommand(cliConfig: CliConfig) extends ListCommand(cliConfig) {
-  override def doRun(): Seq[ServiceNodeInfo] = {
+  override def doRun(): Iterable[ServiceNodeInfo] = {
     CtlUtils.listZkServerNodes(conf, normalizedCliConfig, None)
   }
 }
