@@ -55,6 +55,8 @@ public class JdbcConnectionParams {
   public static final String AUTH_KERBEROS_AUTH_TYPE_FROM_KEYTAB = "fromKeytab";
   public static final String AUTH_KERBEROS_AUTH_TYPE_FROM_SUBJECT = "fromSubject";
   public static final String AUTH_KERBEROS_AUTH_TYPE_FROM_TICKET_CACHE = "fromTicketCache";
+  public static final String AUTH_KERBEROS_ENABLE_CANONICAL_HOSTNAME_CHECK =
+      "kerberosEnableCanonicalHostnameCheck";
   public static final String AUTH_TYPE_JWT = "jwt";
   public static final String AUTH_TYPE_JWT_KEY = "jwt";
   public static final String AUTH_JWT_ENV = "JWT";
