@@ -17,7 +17,7 @@
 
 package org.apache.kyuubi.jdbc.hive;
 
-import static org.apache.hive.service.rpc.thrift.TTypeId.*;
+import static org.apache.kyuubi.shaded.hive.service.rpc.thrift.TTypeId.*;
 
 import java.sql.*;
 import java.util.ArrayList;
@@ -25,10 +25,10 @@ import java.util.Arrays;
 import java.util.Comparator;
 import java.util.List;
 import java.util.jar.Attributes;
-import org.apache.hive.service.rpc.thrift.*;
 import org.apache.kyuubi.jdbc.KyuubiHiveDriver;
 import org.apache.kyuubi.jdbc.hive.adapter.SQLDatabaseMetaData;
-import org.apache.thrift.TException;
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift.*;
+import org.apache.kyuubi.shaded.thrift.TException;
 
 /** KyuubiDatabaseMetaData. */
 public class KyuubiDatabaseMetaData implements SQLDatabaseMetaData {
