@@ -26,13 +26,14 @@ import com.fasterxml.jackson.module.scala.DefaultScalaModule
 import org.apache.kyuubi.Logging
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.engine.ApplicationState.ApplicationState
+import org.apache.kyuubi.server.metadata.MetadataManager
 
 trait ApplicationOperation {
 
   /**
    * Step for initializing the instance.
    */
-  def initialize(conf: KyuubiConf): Unit
+  def initialize(conf: KyuubiConf, metadataManager: Option[MetadataManager]): Unit
 
   /**
    * Step to clean up the instance
@@ -112,7 +113,9 @@ case class ApplicationInfo(
     name: String,
     state: ApplicationState,
     url: Option[String] = None,
-    error: Option[String] = None) {
+    error: Option[String] = None,
+    // only used for K8s and still possible to be None for cases like NOT_FOUND state for K8s cases
+    podName: Option[String] = None) {
 
   def toMap: Map[String, String] = {
     Map(
@@ -120,7 +123,8 @@ case class ApplicationInfo(
       "name" -> name,
       "state" -> state.toString,
       "url" -> url.orNull,
-      "error" -> error.orNull)
+      "error" -> error.orNull) ++
+      podName.map("podName" -> _).toMap
   }
 }
 
