@@ -34,7 +34,5 @@ WHERE a.ca_address_sk = c.c_current_addr_sk
   WHERE j.i_category = i.i_category)
 GROUP BY a.ca_state
 HAVING count(*) >= 10
--- order-by list of q6 in TPCDS v1.4 is below:
--- order by cnt
-order by cnt, a.ca_state
+ORDER BY cnt
 LIMIT 100
