@@ -17,8 +17,11 @@
 
 package org.apache.kyuubi.engine
 
+import io.fabric8.kubernetes.api.model.{ContainerState, ContainerStateWaiting}
+
 import org.apache.kyuubi.{KyuubiException, KyuubiFunSuite}
 import org.apache.kyuubi.config.KyuubiConf
+import org.apache.kyuubi.engine.ApplicationState.{FAILED, PENDING}
 
 class KubernetesApplicationOperationSuite extends KyuubiFunSuite {
 
@@ -113,4 +116,46 @@ class KubernetesApplicationOperationSuite extends KyuubiFunSuite {
         KubernetesInfo(Some("c1"), None),
         KubernetesInfo(None, Some("ns1"))))
   }
+
+  test("containerStateToApplicationState waiting reasons") {
+    // Only valid pending reasons: ContainerCreating and PodInitializing
+    val pendingWaitingReasons = Set("ContainerCreating", "PodInitializing")
+
+    pendingWaitingReasons.foreach { reason =>
+      val containerState = new ContainerState()
+      val waiting = new ContainerStateWaiting()
+      waiting.setReason(reason)
+      containerState.setWaiting(waiting)
+
+      val result = KubernetesApplicationOperation.containerStateToApplicationState(containerState)
+      assert(result === PENDING)
+    }
+  }
+
+  test("containerStateToApplicationState failure reasons and empty reason") {
+    val failureReasons = Set(
+      "ErrImagePull",
+      "ImagePullBackOff",
+      "CrashLoopBackOff",
+      "CreateContainerConfigError")
+
+    failureReasons.foreach { reason =>
+      val containerState = new ContainerState()
+      val waiting = new ContainerStateWaiting()
+      waiting.setReason(reason)
+      containerState.setWaiting(waiting)
+
+      val result = KubernetesApplicationOperation.containerStateToApplicationState(containerState)
+      assert(result === FAILED)
+    }
+
+    // Empty/null reason should be treated as PENDING (still initializing)
+    val containerStateEmpty = new ContainerState()
+    val waitingEmpty = new ContainerStateWaiting()
+    waitingEmpty.setReason(null)
+    containerStateEmpty.setWaiting(waitingEmpty)
+    val resultEmpty =
+      KubernetesApplicationOperation.containerStateToApplicationState(containerStateEmpty)
+    assert(resultEmpty === PENDING)
+  }
 }
